@@ -23,7 +23,7 @@ class VHDLTest(object):
     _test_result: Dict[str, RunResults]
 
     # VHDLTest version
-    version = "0.1.1"
+    version = "0.2.0"
 
     def __init__(self) -> None:
         """Initialize a new VHDLTest instance."""
@@ -43,13 +43,15 @@ class VHDLTest(object):
         """Parse command-line arguments into _args."""
         # Construct the argument parser
         parser = argparse.ArgumentParser(
-            prog='VHDL Testbench Runner (VHDLTest)',
-            description='''Runs VHDL Testbenches and generates a report of the
+            prog='VHDL Test-bench Runner (VHDLTest)',
+            description='''Runs VHDL Test-benches and generates a report of the
                          passes and failures. Reference documentation is located
                          at https://github.com/Malcolmnixon/VhdlTest''')
         parser.add_argument('-c', '--config', help='Configuration file')
         parser.add_argument('-l', '--log', help='Write to log file')
         parser.add_argument('-j', '--junit', help='Generate JUnit xml file')
+        parser.add_argument('-t', '--tests', nargs='+', help='List of test-benches to run')
+        parser.add_argument('-s', '--simulator', default='', help='Specify simulator (E.G. GHDL)')
         parser.add_argument('-v', '--verbose', default=False, action='store_true', help='Verbose logging of output')
         parser.add_argument('--exit-0', default=False, action='store_true', help='Exit with code 0 even if tests fail')
         parser.add_argument('--version', default=False, action='store_true', help='Display version information')
@@ -64,7 +66,7 @@ class VHDLTest(object):
 
         # Check for version
         if self._args.version:
-            print(f'VHDL Testbench Runner (VHDLTest) version {VHDLTest.version}')
+            print(f'VHDL Test-bench Runner (VHDLTest) version {VHDLTest.version}')
             sys.exit(0)
 
         # Ensure we have a configuration
@@ -135,7 +137,7 @@ class VHDLTest(object):
             result = self._test_results[test]
 
             # Create the test case
-            test_case = TestCase('all', classname=test, elapsed_sec=result.duration, stdout=result.output)
+            test_case = TestCase(test, classname=test, elapsed_sec=result.duration, stdout=result.output)
 
             # Detect failures or errors
             if result.failure:
@@ -198,18 +200,24 @@ class VHDLTest(object):
             self._log.add_log_file(self._args.log)
 
         # Print the banner and capture the start time
-        self._log.write('VHDL Testbench Runner (VHDLTest)\n\n')
+        self._log.write('VHDL Test-bench Runner (VHDLTest)\n\n')
         elapsed_start = datetime.now()
 
         # Read the configuration
         self._config = Configuration(self._args.config)
+
+        # Override configuration with command line arguments
+        if self._args.tests:
+            self._config.tests = self._args.tests
+
+        # Count the number of tests
         self._test_count = len(self._config.tests)
 
         # Create a simulator
-        self._simulator = SimulatorFactory.create_simulator()
+        self._simulator = SimulatorFactory.create_simulator(self._args.simulator)
         if self._simulator is None:
             self._log.write(Log.error,
-                            'Error: No simulator installed. Please add a simulator to the path',
+                            'Error: Simulator not found. Please add simulator to the path',
                             Log.end,
                             '\n')
             sys.exit(1)
